# Population dynamics

Library to conduct experiements on population dynamics.

![Lotka-Volterra predator-prey system](./graphics/predator_prey.png)

## Installation

1. Create conda environment
```
conda env create -f environment.yml
```
2. Activate the environment
```
source activate population-dynamics
```
3. Install `causal` as a package within the environment
```
python install_causal.py develop
```
4. To setup all the log and results folders, run
```
bash setup.sh
```
